/*! base64-u8array-arraybuffer v1.0.1 | MIT */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.base64u8ArrayBuffer = {}));
}(this, (function (exports) { 'use strict';

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return _arrayLikeToArray(arr);
  }

  function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
  }

  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }

  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;

    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

    return arr2;
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var runningOnBrowser = typeof window !== 'undefined';

  var base64urlToBase64 = function base64urlToBase64(base64UrlString) {
    // Replace non-url compatible chars with base64 standard chars
    var base64 = base64UrlString.replace(/-/g, '+').replace(/_/g, '/'); // Pad out with standard base64 required padding characters if missing

    var missingPadding = '='.repeat((4 - base64.length % 4) % 4);
    return base64 + missingPadding;
  };

  var base64Decode = function base64Decode(data) {
    if (runningOnBrowser) {
      return atob(data);
    } // atob polyfill for Node


    return Buffer.from(data, 'base64').toString('binary');
  };

  var base64ToUint8Array = function base64ToUint8Array(base64String) {
    // base64 sanitizing
    var base64 = base64urlToBase64(base64String); // base64 decoding

    var rawData = base64Decode(base64); // Converting raw data to Uint8Array

    return Uint8Array.from(rawData, function (_char) {
      return _char.charCodeAt(0);
    });
  };

  var typedArrayToBase64 = function typedArrayToBase64(typedArray) {
    if (runningOnBrowser) {
      return btoa(String.fromCharCode.apply(String, _toConsumableArray(typedArray)));
    }

    return Buffer.from(typedArray).toString('base64');
  };

  var uint8ArrayToBase64 = typedArrayToBase64;

  var typedArrayToArrayBuffer = function typedArrayToArrayBuffer(typedArray) {
    return typedArray.buffer;
  };

  var uint8ArrayToArrayBuffer = typedArrayToArrayBuffer;

  var arrayBufferToUint8Array = function arrayBufferToUint8Array(arrayBuffer) {
    return new Uint8Array(arrayBuffer);
  };

  var base64ToArrayBuffer = function base64ToArrayBuffer(base64String) {
    var uint8Array = base64ToUint8Array(base64String);
    return uint8ArrayToArrayBuffer(uint8Array);
  };

  var arrayBufferToBase64 = function arrayBufferToBase64(arrayBuffer) {
    var uint8Array = arrayBufferToUint8Array(arrayBuffer);
    return uint8ArrayToBase64(uint8Array);
  };

  exports.arrayBufferToBase64 = arrayBufferToBase64;
  exports.arrayBufferToUint8Array = arrayBufferToUint8Array;
  exports.base64ToArrayBuffer = base64ToArrayBuffer;
  exports.base64ToUint8Array = base64ToUint8Array;
  exports.typedArrayToArrayBuffer = typedArrayToArrayBuffer;
  exports.typedArrayToBase64 = typedArrayToBase64;
  exports.uint8ArrayToArrayBuffer = uint8ArrayToArrayBuffer;
  exports.uint8ArrayToBase64 = uint8ArrayToBase64;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
